==> gcalctool-5.9.10.tar.gz: gcalctool-5.9.10/gcalctool/ce_parser.tab.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     tABS = 258,
     tACOS = 259,
     tACOSH = 260,
     tAND = 261,
     tANS = 262,
     tASIN = 263,
     tASINH = 264,
     tATAN = 265,
     tATANH = 266,
     tCBRT = 267,
     tCHS = 268,
     tCLR = 269,
     tCOS = 270,
     tCOSH = 271,
     tCTRM = 272,
     tDDB = 273,
     tEXP = 274,
     tFRAC = 275,
     tFV = 276,
     tINT = 277,
     tLN = 278,
     tLOG10 = 279,
     tMOD = 280,
     tNOT = 281,
     tOR = 282,
     tPI = 283,
     tPMT = 284,
     tPV = 285,
     tRAND = 286,
     tRATE = 287,
     tRCL = 288,
     tSIN = 289,
     tSINH = 290,
     tSLN = 291,
     tSQRT = 292,
     tSTO = 293,
     tSYD = 294,
     tTAN = 295,
     tTANH = 296,
     tTERM = 297,
     tU16 = 298,
     tU32 = 299,
     tXNOR = 300,
     tXOR = 301,
     tINUMBER = 302,
     tDNUMBER = 303,
     tREG = 304,
     NEG = 305,
     MED = 306,
     POS = 307,
     HIGH = 308
   };
#endif
/* Tokens.  */
#define tABS 258
#define tACOS 259
#define tACOSH 260
#define tAND 261
#define tANS 262
#define tASIN 263
#define tASINH 264
#define tATAN 265
#define tATANH 266
#define tCBRT 267
#define tCHS 268
#define tCLR 269
#define tCOS 270
#define tCOSH 271
#define tCTRM 272
#define tDDB 273
#define tEXP 274
#define tFRAC 275
#define tFV 276
#define tINT 277
#define tLN 278
#define tLOG10 279
#define tMOD 280
#define tNOT 281
#define tOR 282
#define tPI 283
#define tPMT 284
#define tPV 285
#define tRAND 286
#define tRATE 287
#define tRCL 288
#define tSIN 289
#define tSINH 290
#define tSLN 291
#define tSQRT 292
#define tSTO 293
#define tSYD 294
#define tTAN 295
#define tTANH 296
#define tTERM 297
#define tU16 298
#define tU32 299
#define tXNOR 300
#define tXOR 301
#define tINUMBER 302
#define tDNUMBER 303
#define tREG 304
#define NEG 305
#define MED 306
#define POS 307
#define HIGH 308




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 38 "./ce_parser.y"
{
  int int_t[MP_SIZE];
  int integer;
}
/* Line 1529 of yacc.c.  */
#line 160 "ce_parser.tab.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE celval;

==> gcalctool-5.21.0.tar.gz: gcalctool-5.21.0/gcalctool/ce_parser.tab.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     tABS = 258,
     tACOS = 259,
     tACOSH = 260,
     tAND = 261,
     tANS = 262,
     tASIN = 263,
     tASINH = 264,
     tATAN = 265,
     tATANH = 266,
     tCBRT = 267,
     tCHS = 268,
     tCLR = 269,
     tCOS = 270,
     tCOSH = 271,
     tCTRM = 272,
     tDDB = 273,
     tEXP = 274,
     tFRAC = 275,
     tFV = 276,
     tINT = 277,
     tLN = 278,
     tLOG10 = 279,
     tMOD = 280,
     tNOT = 281,
     tOR = 282,
     tPI = 283,
     tPMT = 284,
     tPV = 285,
     tRAND = 286,
     tRATE = 287,
     tRCL = 288,
     tSIN = 289,
     tSINH = 290,
     tSLN = 291,
     tSQRT = 292,
     tSTO = 293,
     tSYD = 294,
     tTAN = 295,
     tTANH = 296,
     tTERM = 297,
     tU16 = 298,
     tU32 = 299,
     tXNOR = 300,
     tXOR = 301,
     tNUMBER = 302,
     tREG = 303,
     NEG = 304,
     MED = 305,
     POS = 306,
     HIGH = 307
   };
#endif
/* Tokens.  */
#define tABS 258
#define tACOS 259
#define tACOSH 260
#define tAND 261
#define tANS 262
#define tASIN 263
#define tASINH 264
#define tATAN 265
#define tATANH 266
#define tCBRT 267
#define tCHS 268
#define tCLR 269
#define tCOS 270
#define tCOSH 271
#define tCTRM 272
#define tDDB 273
#define tEXP 274
#define tFRAC 275
#define tFV 276
#define tINT 277
#define tLN 278
#define tLOG10 279
#define tMOD 280
#define tNOT 281
#define tOR 282
#define tPI 283
#define tPMT 284
#define tPV 285
#define tRAND 286
#define tRATE 287
#define tRCL 288
#define tSIN 289
#define tSINH 290
#define tSLN 291
#define tSQRT 292
#define tSTO 293
#define tSYD 294
#define tTAN 295
#define tTANH 296
#define tTERM 297
#define tU16 298
#define tU32 299
#define tXNOR 300
#define tXOR 301
#define tNUMBER 302
#define tREG 303
#define NEG 304
#define MED 305
#define POS 306
#define HIGH 307




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 38 "./ce_parser.y"
{
  int int_t[MP_SIZE];
  int integer;
}
/* Line 1489 of yacc.c.  */
#line 158 "ce_parser.tab.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE celval;
